@@ -2,9 +2,9 @@ from allosaurus.pm.mfcc import MFCC
 import json
 from argparse import Namespace
 
-def read_pm(model_path):
+def read_pm(model_path, inference_config):
     """
-    simple factor method for feature model
+    read feature extraction model
 
     :param pm_config:
     :return:
