@@ -16,5 +16,12 @@ class TestRecognition(unittest.TestCase):
         results = model.recognize(audio_file, 'eng')
         self.assertTrue(len(results) > 0)
 
+    def test_eng_nonempty_external_model(self):
+        audio_file = Path(__file__).parent.parent / 'sample.wav'
+        model_path = Path(__file__).parent.parent / 'test_model'
+        model = read_recognizer('latest', model_path)
+        results = model.recognize(audio_file, 'eng')
+        self.assertTrue(len(results) > 0)
+
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
